# Overview

# Q-learning algorithms

# Recipies

## Carpole

An inverted pendulum on a cart initially developed by Chuck Anderson (chuck.anderson@colostate.edu).

Solutions currently implemented using SCG, SGD (does not solve), and Adam (also not solved).

# Other stuff:

## How to create package

<source >

python3 setup.py sdist bdist_wheel

python3 -m twine upload dist/*

</source>

# To create a private release

<code>
   $ python3 setup.py sdist bdist_wheel
</code>

